# pyZink
 Personal package of python utilities and scripts that I use, and that others might use

## Installation (If downloading from Github, not PyPI/pip)
(Installation tested on Windows 11 23H2)
1. Clone or download the repository (place it in a permament location if downloaded)
2. Execute install_package.py
3. Reload any running VSCode windows using `Ctrl + Shift + P > Reload Window` inside VSCode

## Uninstallation (If downloading from Github, not PyPI/pip)
So, you decided pyZink wasn't for you. That's okay (: Follow these steps:
1. Execute uninstall_package.py
2. Remove the repository it's contensts

## Usage
1. Import the package in your script `import pyZink.connect.ssh` > `ssh = pyZink.connect.ssh.SSH_Client()` etc.

## License
This repository is licensed under the GPL-3.0 license. Read more in the LICENSE-file

## Changelog
Changes of major versions will appear here, when they are made

## Contactt
Issues can be submitted on Github at https://github.com/Peasniped/pyZink/issues